@@ -20,9 +20,15 @@ from  flashcam.stream_enhancer import Stream_Enhancer
 
 from flashcam import v4lc
 
+from flashcam.mmapwr import mmread_n_clear
 
 
 
+
+# -----------------------------------------------------------------
+
+# -----------------------------------------------------------------
+
 class Camera(BaseCamera):
     video_source = 0
 
@@ -72,6 +78,10 @@ class Camera(BaseCamera):
         """
         recommended= ... uses the recommend_video to restart the same cam
         """
+        # i need these to be in globals() ----evaluate from web.py
+        global substract_background,save_background
+        global speedx, speedy, restart_translate, average
+
         # print("i... staticmethod frames @ real -  enterred; target_frame==", target_frame)
         senh = Stream_Enhancer()
 
@@ -86,6 +96,11 @@ class Camera(BaseCamera):
         speedx          = float(config.CONFIG['x'])
         speedy          = float(config.CONFIG['y'])
 
+        # ------------------    to evaluate commands from web.py
+        substract_background = False
+        save_background = False
+        restart_translate = False
+
         camera = Camera(  )
         cap, vidnum = camera.init_cam(  )
 
@@ -176,7 +191,7 @@ class Camera(BaseCamera):
                     print("X... prev_frame was bad, no gray image")
 
             #print("D... ret==", ret)
-            if ret:
+            if ret: #********************************************************* operations
                 frame_prev = frame
                 if senh.add_frame(frame):  # it is a proper image....
 
@@ -195,12 +210,11 @@ class Camera(BaseCamera):
                         if "exposure" in capa:
                             exposure = cc.get_exposure()
 
-                        # --- crashing with C120
                         if "exposure_auto" in capa:  # if not auto, always tell _absolute
                             expo_auto = cc.get_exposure_auto()
                             expo_autodef = cc.getdef_exposure_auto()
+                            print(f"i... EXPOAUTO == {expo_auto} vs def={expo_autodef}; ")
 
-                        # --- crashing with C120
                         if "exposure_absolute" in capa:
                             exposure_absolute = cc.get_exposure_absolute()
 
@@ -211,23 +225,47 @@ class Camera(BaseCamera):
                         if "gamma" in capa:
                             gamma = cc.get_gamma()
                             gammadef = cc.getdef_gamma()
-                        print(f"i... EXPOAUTO == {expo_auto} vs def={expo_autodef}; ")
                     #--------------------------------------------------------------------------
 
 
 
+
                     # ----------  I need to calculate histogram before labels...
                     if histogram: # just calculate a number on plain frame
                         hmean = senh.histo_mean( )
 
-                    if False:
-                        print("D... HERE I MUST GIVE subtraction of mask")
+                    # ---------- before anything - we decode the web command
+                    expression,value = mmread_n_clear( )
+                    #print(f"i... expression == {expression}  value == {value}")
+                    globals()[expression] = eval(value)
+                    # print(".... substract_background", substract_background, not(substract_background) )
+                    # globals()["substract_background"] = value
+
+                    if save_background:
+                        print("D... HERE I SAVE save_background of mask")
+                        print("D... HERE I SAVE save_background of mask")
+                        print("D... HERE I SAVE save_background of mask")
+                        senh.save_background()
+                        save_background = False  # ONE SHOT
+
+                    if substract_background:
+                        print("D... HERE I MUST DO subtraction of mask")
+                        print("D... HERE I MUST DO subtraction of mask")
+                        print("D... HERE I MUST DO subtraction of mask")
                         senh.subtract()
 
                     # - compensate for speed of the sky
                     if (speedx!=0) or (speedy!=0):
                         senh.translate( speedx, speedy)
 
+                    if restart_translate:
+                        senh.reset_camera_start()
+                        restart_translate = False
+
+                    # average  THIS IS HERE to be changed TOO
+                    # print("i.... average", average)
+
+
                     #--------------- now apply labels ------i cannot get rid in DETM---
                     #--------- all this will be on all rames histo,detect,direct,delta
                     senh.setbox(" ", senh.TIME)
@@ -243,6 +281,11 @@ class Camera(BaseCamera):
                         senh.setbox(f"laps {timelaps}",  senh.lap)
                     if histogram:
                         senh.setbox(f"his {hmean:3.0f}",  senh.hist)
+                    if speedx!=0:
+                        #print(speedx)
+                        senh.setbox(f"x {speedx:.3f}",  senh.speedx)
+                    if speedy!=0:
+                        senh.setbox(f"y {speedy:.3f}",  senh.speedy)
 
 
                     # very stupid camera    ZC0303 Webcam
