@@ -264,8 +264,8 @@ def display2(videodev, save = False,
                                         len(bytex)/1024,
                                         BPSlast*8/1024,
                                         FPSlast,
-                                        datetime.datetime.now(),
-                                        sfilenamea
+                                        str(datetime.datetime.now())[:-5],
+                                        sfilenamea.replace('/home/','')
                                     ) , end="\r")
 
                                 else:
@@ -321,6 +321,11 @@ def display2(videodev, save = False,
                     sfilenamea,saviout = setupsave()
                     print(">>>", sfilenamea )
 
+                if (not frame is None) and (rpi_name!="") and (key == ord('z')):
+                    print("Z PRESSED! - STOPPING stopping saving AVI")
+                    save = False
+                    sfilenamea = ""
+
                 if (not frame is None) and (rpi_name!="") and (key == ord('q')):
                     print("Q PRESSED!")
                     sys.exit(1)
