@@ -40,6 +40,12 @@ import numpy as np
 
 from flashcam.real_camera import Camera
 
+#----------------------------------------------
+from flashcam.mmapwr import mmwrite
+
+
+
+
 app = Flask(__name__)
 
 
@@ -130,7 +136,7 @@ setInterval(doDate, 200);
   </div>
   <div class="btn-group" style="width:100%">
       <button style="width:20%" name="up" value="UP">up</button>
-      <button style="width:10%" name="crosson" value="CROSSON">CROSSON</button>
+      <button style="width:10%" name="crosson" value="CROSSON">crossON</button>
   </div>
   <div class="btn-group" style="width:100%">
       <button style="width:3%" name="left2" value="LEFT2"> << </button>
@@ -141,20 +147,32 @@ setInterval(doDate, 200);
   </div>
   <div class="btn-group" style="width:100%">
       <button style="width:20%" name="down" value="DOWN">down</button>
-      <button style="width:10%" name="crossoff" value="CROSSOFF">CROSSOFF</button>
+      <button style="width:10%" name="crossoff" value="CROSSOFF">crossOFF</button>
   </div>
   <div class="btn-group" style="width:100%">
       <button style="width:20%" name="down2" value="DOWN2">down2</button>
   </div>
 <hr>
   <div class="btn-group" style="width:100%">
-      <button style="width:8%" name="savebg" value="SAVEBG">SAVEBG</button>
-      <button style="width:8%" name="subbg" value="SUBBG">SUBBG</button>
-  </div>
-</form>
+      <button style="width:8%" name="savebg" value="SAVEBG">saveBG</button>
+      <button style="width:8%" name="subbg" value="SUBBG">subBG</button>
  <img src="{{url_bg}}" alt="Smiley face"  height="120" width="160" />
+<hr>
+  <p>    <button style="width:8%" name="speedx" value="SPEEDX">dXdY</button>
+      <!--button style="width:8%" name="speedy" value="SPEEDY">dY</button-->
+dx <input type = "text" name = "inputx"  size="6" />  dy <input type = "text" name = "inputy" size="6" />
+
+      <button style="width:8%" name="restart_translate" value="RESTART_TRANSLATE">restart</button>
+      <button style="width:8%" name="zero_translate" value="ZERO_TRANSLATE">zero</button>
+<br>
+   <p>   <button style="width:8%" name="accum" value="ACCUM">Accum</button>
+      accum <input type = "text" name = "accumtxt" size="6" /></p>
+  </div>
+
+</form>
+
+
 
-operate real from web
   </body>
 </html>
 
@@ -180,6 +198,7 @@ def crossonw( img,  dix, diy):
     return img
 
 
+
 @auth.verify_password
 @app.route("/cross", methods=['GET', 'POST'])
 def cross():
@@ -196,9 +215,52 @@ def cross():
         if request.form.get('savebg') == 'SAVEBG':
             print("i... saving BG" )
             save_bg = True
+            mmwrite(f"save_background {save_bg}" )
+
         if request.form.get('subbg') == 'SUBBG':
             print("i... substracting  BG" )
             sub_bg = not( sub_bg)
+            mmwrite(f"substract_background {sub_bg}" )
+
+        if request.form.get('accum') == 'ACCUM':
+            accum = request.form.get('accumtxt')
+            try:
+                accum = int(accum)
+            except:
+                accum = 0
+            print("i...  ACCUM",  accum)
+            mmwrite(f"average {accum}" )
+
+        if request.form.get('speedx') == 'SPEEDX':
+            speedx = request.form.get('inputx')
+            try:
+                speedx = float(speedx)
+            except:
+                speedx = 0.0
+            print("i...  X",  speedx)
+            mmwrite(f"speedx {speedx}" )
+
+        #if request.form.get('speedy') == 'SPEEDY':
+            speedy = request.form.get('inputy')
+            try:
+                speedy = float(speedy)
+            except:
+                speedy = 0.0
+            print("i...  Y",  speedy)
+            #print("i... Y" )
+            time.sleep(0.2)
+            mmwrite(f"speedy {speedy}" )
+
+        if request.form.get('restart_translate') == 'RESTART_TRANSLATE':
+            mmwrite(f"restart_translate True" )
+
+        if request.form.get('zero_translate') == 'ZERO_TRANSLATE':
+            mmwrite(f"speedx {0}" )
+            time.sleep(0.2)
+            mmwrite(f"speedy {0}" )
+
+
+
         if cross_on:
             if request.form.get('left2') == 'LEFT2':
                 print("left2")
@@ -236,6 +298,7 @@ def cross():
             print("OFF")
             cross_on = False
 
+        # .... save cross x and y inside a file at ~/.config/flashcam/
         with open(crocfg,"w") as f:
             f.write(f"{cross_dx} {cross_dy}")
 
@@ -244,6 +307,7 @@ def cross():
     logthis( " / remote xreal= "+remote_ip )
     url = url_for('video')
     url_bg = url_for('background')
+    #time.sleep(0.5)
     return render_template_string(index_page, url=url, url_bg  = url_bg)
 
 
@@ -313,26 +377,26 @@ def index30():
 @app.route('/background')
 @auth.login_required
 def background():
-    global  save_bg, frame_bg, frame_bg2, frame_mask, frame_mask_inv, BGFILE
-    if not(frame_bg is None):
-        # print(frame_bg, "BGFRAME")
-        # # frame = cv2.imdecode(frame_bg, cv2.IMREAD_COLOR)
-        r, jpg = cv2.imencode('.jpg', frame_bg)
-        print("RESPONSE BACKGROUND",r)
+    global  save_bg, frame_bg, frame_bg2, frame_mask, frame_mask_inv #, BGFILE
+    #if not(frame_bg is None):
+    #    # print(frame_bg, "BGFRAME")
+    #    # # frame = cv2.imdecode(frame_bg, cv2.IMREAD_COLOR)
+    #    r, jpg = cv2.imencode('.jpg', frame_bg)
+    #    # print("RESPONSE BACKGROUND",r)
+    #else:
+    if os.path.exists( BGFILE):
+        blank = cv2.imread( BGFILE )
+        # print( blank )
+        # # frame_bg = cv2.imdecode(blank, cv2.IMREAD_COLOR)
+        frame_bg = blank.copy() # propagate to the system
+        r, jpg = cv2.imencode('.jpg', blank)
+        print("OLD BACKGROUND IMAGE FOUND",r, frame_bg.shape)
     else:
-        if os.path.exists( BGFILE):
-            blank = cv2.imread( BGFILE )
-            # print( blank )
-            # # frame_bg = cv2.imdecode(blank, cv2.IMREAD_COLOR)
-            frame_bg = blank.copy() # propagate to the system
-            r, jpg = cv2.imencode('.jpg', blank)
-            print("OLD BACKGROUND IMAGE FOUND",r, frame_bg.shape)
-        else:
-            blank = np.zeros((480,640,3), np.uint8)
-            frame_bg = blank.copy() # propagate to the system
-            #frame = cv2.imdecode(blank, cv2.IMREAD_COLOR)
-            r, jpg = cv2.imencode('.jpg', blank)
-            print("NO BACKGROUND - black image",r)
+        blank = np.zeros((480,640,3), np.uint8)
+        frame_bg = blank.copy() # propagate to the system
+        #frame = cv2.imdecode(blank, cv2.IMREAD_COLOR)
+        r, jpg = cv2.imencode('.jpg', blank)
+        print("NO BACKGROUND - black image",r)
 
     # create mask----------------- appears not usefull-----
     # frame_mask = np.random.randint(2,
@@ -400,26 +464,25 @@ def gen(camera, remote_ip, blend=False, bigtext=True):
         if cross_on:
             frame = crossonw( frame, cross_dx, cross_dy )
 
-        if save_bg:# before .tobytes()
-            cv2.imwrite( BGFILE , frame )
-            frame_bg = frame.copy()
-            frame_bg2 = cv2.imencode('.jpg', frame_bg)[1].tobytes()
-            save_bg = False
+        # if save_bg:# before .tobytes()
+        #     cv2.imwrite( BGFILE , frame )
+        #     frame_bg = frame.copy()
+        #     frame_bg2 = cv2.imencode('.jpg', frame_bg)[1].tobytes()
+        #     save_bg = False
 
-        if sub_bg and  not(frame_bg is None):
-            # print( frame_mask.shape )
-            # print( frame_bg.shape )
-            # print( frame.shape )
-            frame1 = cv2.subtract(frame , frame_bg ) #, mask = frame_mask
-            # frame = cv2.subtract( frame_bg, frame) # inverse...
-            # frame = cv2.absdiff(frame , frame_bg) # returns abs value...
-            # frame = cv2.absdiff(frame_bg, frame) # returns abs value...
-
-            # frame 1 is difference...
-            frame1[:22,:] = frame [:22,:]
-            frame1[-22:,:] = frame [-22:,:]
-            frame = frame1
-            #frame = cv2.add( frame, frame1, mask = frame_mask_inv )
+        # if sub_bg and  not(frame_bg is None):
+        #     # print( frame_mask.shape )
+        #     # print( frame_bg.shape )
+        #     # print( frame.shape )
+        #     frame1 = cv2.subtract(frame , frame_bg ) #, mask = frame_mask
+        #     # frame = cv2.subtract( frame_bg, frame) # inverse...
+        #     # frame = cv2.absdiff(frame , frame_bg) # returns abs value...
+        #     # frame = cv2.absdiff(frame_bg, frame) # returns abs value...
+        #     # frame 1 is difference...
+        #     frame1[:22,:] = frame [:22,:]
+        #     frame1[-22:,:] = frame [-22:,:]
+        #     frame = frame1
+        #     # frame = cv2.add( frame, frame1, mask = frame_mask_inv )
 
         if not(frame is None):
             frame=cv2.imencode('.jpg', frame)[1].tobytes()
@@ -438,54 +501,9 @@ def gen(camera, remote_ip, blend=False, bigtext=True):
                b'Content-Type: image/jpeg\r\n\r\n' + frame + b'\r\n')
 
 
-# @app.before_first_request
-# def debug_print():
-
-#     class Bcolors:
-#         HEADER = '[95m'
-#         OKBLUE = '[94m'
-#         OKGREEN = '[92m'
-#         WARNING = '[93m'
-#         FAIL = '[91m'
-#         ENDC = '[0m'
-#         BOLD = '[1m'
-#         UNDERLINE = '[4m'
-
-#         #    if not(config.CONFIG["debug"]):
-#         print("X... NO DEBUG colors in main")
-#         _print = print # keep a local copy of the original print
-#         builtins.print =lambda *args, **kwargs:  None  if (isinstance(args[0], str)) and (args[0].find("D...")==0) else  _print( *args, **kwargs) if ('file' in kwargs) else _print( "{}".format(Bcolors.FAIL   if ((isinstance(args[0], str)) and (args[0].find("X...")>=0)) else Bcolors.ENDC) , *args, Bcolors.ENDC, **kwargs, file=sys.stderr)
-# #    else:
-# #        print("X... DEBUG COLORS FROM MAIN")
-# #        # debug - show all + colors
-# #        _print = print # keep a local copy of the original print
-# #        builtins.print =lambda *args, **kwargs:   _print( *args, **kwargs) if ('file' in kwargs) else _print( "{}".format(Bcolors.FAIL   if ((isinstance(args[0], str)) and (args[0].find("X...")>=0)) else Bcolors.OKGREEN if  ((isinstance(args[0], str)) and (args[0].find("i...")>=0)) else Bcolors.ENDC  ), *args, Bcolors.ENDC, **kwargs, file=sys.stderr)
-
 
 if __name__ == '__main__':
 
-    # class Bcolors:
-    #     HEADER = '[95m'
-    #     OKBLUE = '[94m'
-    #     OKGREEN = '[92m'
-    #     WARNING = '[93m'
-    #     FAIL = '[91m'
-    #     ENDC = '[0m'
-    #     BOLD = '[1m'
-    #     UNDERLINE = '[4m'
 
-    # if True:
-    #     _print = print # keep a local copy of the original print
-    #     builtins.print =lambda *args, **kwargs:  None  if (isinstance(args[0], str)) and (args[0].find("D...")==0) else  _print( *args, **kwargs) if ('file' in kwargs) else _print( "{}".format(Bcolors.FAIL   if ((isinstance(args[0], str)) and (args[0].find("X...")>=0)) else Bcolors.ENDC) , *args, Bcolors.ENDC, **kwargs, file=sys.stderr)
-    # else:
-    #     # debug - show all + colors
-    #     _print = print # keep a local copy of the original print
-    #     builtins.print =lambda *args, **kwargs:   _print( *args, **kwargs) if ('file' in kwargs) else _print( "{}".format(Bcolors.FAIL   if ((isinstance(args[0], str)) and (args[0].find("X...")>=0)) else Bcolors.OKGREEN if  ((isinstance(args[0], str)) and (args[0].find("i...")>=0)) else Bcolors.ENDC  ), *args, Bcolors.ENDC, **kwargs, file=sys.stderr)
-
-    # very first config should know if pantilt is installed
-    #config.load_config()
-    #if v4i.check_pantilt():
-    #    config.CONFIG['pantilt'] = True
-    #    config.save_config()
     print("i... APP RUN FROM WEB.PY")
     app.run(host='0.0.0.0', port=config.CONFIG['port'], threaded=True)
